local ADDON_NAME = "GearGrinder";

local L = LibStub("AceLocale-3.0"):GetLocale(ADDON_NAME, true);

-- Options for AceOptions

GG_Options = {
	name = L.core.options.name,
	desc = L.core.desc,
	type = "group",
	args = {
		general = {
			name = L.core.options.options,
			type = "group",
			inline = true,
			order = 1,
			args = {
				cinfoVP = { -- Paperdoll VP Information
					name = L.core.options.paperdollVP,
					desc = L.core.options.paperdollVPDesc,
					type = "toggle",
					set = function(i,v) GG:SetVPPaperdoll(v) end,
					get = function(i) return GG:GetVPPaperdoll() end,
					order = 1,
				},
				cinfoGG = { -- Paperdoll VP Cap Information
					name = L.core.options.paperdollVPCap,
					desc = L.core.options.paperdollVPCapDesc,
					type = "toggle",
					set = function(i,v) GG:SetVPCapPaperdoll(v) end,
					get = function(i) return GG:GetVPCapPaperdoll() end,
					order = 2,
				},
				cinfoJP = { -- Paperdoll JP Information
					name = L.core.options.paperdollJP,
					desc = L.core.options.paperdollJPDesc,
					type = "toggle",
					set = function(i,v) GG:SetJPPaperdoll(v) end,
					get = function(i) return GG:GetJPPaperdoll() end,
					order = 3,
				},
				minimap = { -- Minimap Button
					name = L.core.options.minimap,
					desc = L.core.options.minimapDesc,
					type = "toggle",
					set = function(i,v) GG:SetMinimap(v) end,
					get = function(i) return GG:GetMinimap() end,
					order = 4,
				},
				reset_dayofweek = { -- Reset Day of Week
					name = L.core.options.resetDayOfWeek,
					desc = L.core.options.resetDayOfWeekDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetResetDayOfWeek(v) end,
					get = function(i) return GG:GetResetDayOfWeek() end,
					values = { 	
						[1] = "Monday",
						[2] = "Tuesday", 
						[3] = "Wednesday",
						[4] = "Thursday", 
						[5] = "Friday",
						[6] = "Saturday",
						[0] = "Sunday" },
					order = 5,
				},
				reset_hour = { -- Reset Hour of day
					name = L.core.options.resetHour,
					desc = L.core.options.resetHourDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetResetHour(v) end,
					get = function(i) return GG:GetResetHour() end,
					values = { 	
						[0] = "12am",
						[1] = "1am",
						[2] = "2am",
						[3] = "3am",
						[4] = "4am",
						[5] = "5am",
						[6] = "6am",
						[7] = "7am",
						[8] = "8am",
						[9] = "9am",
						[10] = "10am",
						[11] = "11am",
						[12] = "12pm",
						[13] = "1pm",
						[14] = "2pm",
						[15] = "3pm",
						[16] = "4pm",
						[17] = "5pm",
						[18] = "6pm",
						[19] = "7pm",
						[20] = "8pm",
						[21] = "9pm",
						[22] = "10pm",
						[23] = "11pm"},
					order = 6,
				},
				combat = { -- Disable the tooltip if in combat
					name = L.core.options.combat,
					desc = L.core.options.combatDesc,
					type = "toggle",
					set = function(i,v) GG:SetShowCombat(v) end,
					get = function(i) return GG:GetShowCombat() end,
					order = 7,
				},
				ttScale = { -- UI Scale of the tooltip
					name = L.core.options.scale,
					desc = L.core.options.scaleDesc,
					type = "range",
					max = 2,
					min = 0.5,
					step = 0.1,
					set = function(i,v) GG:SetTTScale(v) end,
					get = function(i) return GG:GetTTScale() end,
					order = 8,
				},
			},
		},

		ttContent = {
			name = L.core.options.ttContent,
			type = "group",
			inline = true,
			order = 2,
			cmdHidden = true,
			args = {
				charms = { -- Show Charms
					name = L.core.options.charm,
					desc = L.core.options.charmDesc,
					type = "toggle",
					set = function(i,v) GG:SetCharms(v) end,
					get = function(i) return GG:GetCharms() end,
					order = 1,
				},
				iLevel = { -- Show iLevel
					name = L.core.options.iLevel,
					desc = L.core.options.iLevelDesc,
					type = "toggle",
					set = function(i,v) GG:SetiLevel(v) end,
					get = function(i) return GG:GetiLevel() end,
					order = 2,
				},
				sortOrder = { -- Sort Order
					name = L.core.options.sortOrder,
					desc = L.core.options.sortOrderDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetSortOrder(v) end,
					get = function(i) return GG:GetSortOrder() end,
					values = { 	
						[1] = "Unsorted",
						[2] = "Alphabetical",
						[3] = "Class", 
						[5] = "iLevel",
						[4] = "Valor Points",
						[8] = "VP Cap Progress",
						[6] = "Justice Points",
						[7] = "Charms"},
					order = 3,
				},
				worldBoss = { -- Show World Boss Status
					name = L.core.options.boss,
					desc = L.core.options.bossDesc,
					type = "toggle",
					set = function(i,v) GG:SetWorldBoss(v) end,
					get = function(i) return GG:GetWorldBoss() end,
					order = 4,
				},
				show_Icons = { -- Show the icons on the tooltip
					name = L.core.options.showIcon,
					desc = L.core.options.showIconDesc,
					type = "toggle",
					set = function(i,v) GG:SetShowIcon(v) end,
					get = function(i) return GG:GetShowIcon() end,
					order = 5,
				},
				lfr = { -- Show the LFR section the tooltip
					name = L.core.options.LFR,
					desc = L.core.options.LFRDesc,
					type = "toggle",
					set = function(i,v) GG:SetLFR(v) end,
					get = function(i) return GG:GetLFR() end,
					order = 6,
				},
				filtering = { -- enable/disable character filtering
					name = L.core.options.filtering,
					desc = L.core.options.filteringDesc,
					type = "toggle",
					set = function(i,v) GG:SetFiltering(v) end,
					get = function(i) return GG:GetFiltering() end,
					order = 7,
				},
			},
		},

		ldbOpt = {
			name = L.core.options.ldb,
			type = "group",
			inline = true,
			order = 3,
			cmdHidden = true,
			args = {
				ldbText = {  -- Toggle the LDB Text competely
					name = L.core.options.ldbText,
					desc = L.core.options.ldbTextDesc,
					type = "toggle",
					get = function(i) return GG:GetLDB() end,
					set = function(i,v) GG:SetLDB(v) end,
					order = 1,
				},
				ldbLabel = { -- Toggle the characters name
					name = L.core.options.ldbSource,
					desc = L.core.options.ldbSourceDesc,
					type = "toggle",
					get = function(i) return GG:GetLDBlabel() end,
					set = function(i,v) GG:SetLDBlabel(v) end,
					order = 2,
				},
				ldbTextColor = { -- Toggle the Colorizing of the LDB Text
					name = L.core.options.ldbTextColor,
					desc = L.core.options.ldbTextColorDesc,
					type = "toggle",
					set = function(i,v) GG:SetLDBTextColor(v) end,
					get = function(i) return GG:GetLDBTextColor() end,
					order = 3,
				},
				ldbDisplay = { -- Selection of what to display on the LDB Button
					name = L.core.options.ldbDisplay,
					desc = L.core.options.ldbDisplayDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetLDBDisplay(v) end,
					get = function(i) return GG:GetLDBDisplay() end,
					values = { 	
						[1] = "VP Cap (VP) <JP> [LFR]",
						[2] = "VP Cap (VP) [LFR]",
						[3] = "VP Cap (VP) <JP>",
						[4] = "VP Cap (VP)",
						[5] = "VP Cap [LFR]", 
						[6] = "VP Cap",
						[7] = "VP <JP> [LFR]",
						[8] = "VP <JP>",
						[9] = "VP [LFR]",
						[10] = "LFR",
					},
					order = 4,
				},
				ldbDisplayLock = { -- Toggle the locking of the LDB Text button
					name = L.core.options.ldbDisplayLock,
					desc = L.core.options.ldbDisplayLockDesc,
					type = "toggle",
					set = function(i,v) GG:SetLDBDisplayLock(v) end,
					get = function(i) return GG:GetLDBDisplayLock() end,
					order = 5,
				},
			},
		},
        
		Background = {
			type = "group",
			name = "Background Options",
			guiInline = true,
			order = 4,
			get = function(i) return GG:GetBGGeneric(i) end,
			set = function(i, v) GG:SetBGGeneric(i, v) end,
			args = {
				Texture = {
					type = "select", dialogControl = 'LSM30_Background',
					order = 1,
					name = "Background Texture",
					desc = "Texture to use for the frame's background",
					values = AceGUIWidgetLSMlists.background,
				},
				BorderTexture = {
					type = "select", dialogControl = 'LSM30_Border',
					order = 2,
					name = "Border Texture",
					desc = "Texture to use for the tooltip's border",
					values = AceGUIWidgetLSMlists.border,
				},
				Color = {
					type = "color",
					order = 3,
					name = "Background Color",
					desc = "Tooltip's background color",
					hasAlpha = true,
					get = function(i) return GG:GetBGColor() end,
					set = function(i, r, g, b, a) GG:SetBGColor(r, g, b, a) end,
				},
				BorderColor = {
					type = "color",
					order = 4,
					name = "Border Color",
					desc = "Tooltip's border color",
					hasAlpha = true,
					get = function(i) return GG:GetBGBorderColor() end,
					set = function(i, r, g, b, a) GG:SetBGBorderColor(r, g, b, a)	end,
				},
				Tile = {
					type = "toggle",
					order = 5,
					name = "Tile Background",
					desc = "Tile the background texture",
				},
				TileSize = {
					type = "range",
					order = 6,
					name = "Background Tile Size",
					desc = "The size used to tile the background texture",
					min = 16, max = 256, step = 1,
					disabled = function() return not GG:GetBGTile() end,
				},
				EdgeSize = {
					type = "range",
					order = 7,
					name = "Border Thickness",
					desc = "The thickness of the border",
					min = 1, max = 16, step = 1,
				},
			},
		},		
		
		purge = {
			name = L.core.options.purge,
			desc = L.core.options.purgeDesc,
			type = "execute",
			func = function(i) GG:PurgeDB(false) end,
			confirm = true,
			order = 48,
		},
		-- Console Only
		options = {
			name = L.core.options.name,
			desc = L.core.options.optionDesc,
			type = "input",
			set = function(i) GG:ShowOptions() end,
			hidden = true,
			order = 49,
			guiHidden = true,
			cmdHidden = false,
		},
		debug = { -- Debug mode
			name = 'Debug Mode',
			type = "toggle",
			set = function(i,v) GG:SetDebug(v) end,
			get = function() return GG:GetDebug() end,
			order = 50,
			hidden = true,
			guiHidden = true,
			cmdHidden = false,
		},
	},
};

GG_Defaults = {
	global = {
		reset_hour = 3,			-- Hour the VP Cap is reset ie. 3AM
		reset_dayofweek = 2,	-- Day of week when VP Cap is reset ie. Tuesday
		cinfoVP = true,
		cinfoVPCap = true,
		cinfoJP = true,
		combat = false,			-- don't show in combat
		filtering = true,		-- allow characater filtering.
		ttScale = 1,
		progress_orange = 100,
		progress_yellow = 200,
		JPStandardMax = 4000,
		VPStandardMax = 3000,
		VPStandardCapMax = 1000,
		minimap = {
			hide = false,		-- Minimap Icon
		},
		charms = true,			-- show Charms
		iLevel = true,			-- show iLevel
		sortOrder = 5,			-- sort order of iLevel
		version = 1,			-- Version for future referance
		ldbTextColor = true,	-- LDB Text Colorize?
		ldbText = true,			-- LDB Text
		ldbLabel = false,		-- LDB Label
		ldbDisplay = 1,			-- LDB Text display 
		ldbDisplayLock = false, -- LDB button text display lock
		worldBoss = true,		-- Show World Boss status
		show_Icons = false,		-- Show the Icons on the tooltip
		lfr = true,				-- Show the LFR values on the tooltip

		Background = {
			Texture = "Blizzard Rock",
			BorderTexture = "Blizzard Tooltip",
			Color = {r = 0.5, g = 0.5, b = 0.5, a = 1,},
			BorderColor = {r = 0.95, g = 1, b = 1, a = 1,},
			Tile = false,
			TileSize = 32,
			EdgeSize = 10,
		},
	},
    char = {
        debug = false,          -- Debug mode
    }
};

